==> jena-5.6.0-source-release.zip: jena-5.6.0/jena-core/src/test/java/org/apache/jena/assembler/test/TestMemoryModelAssembler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.assembler.test;

import org.apache.jena.assembler.*;
import org.apache.jena.assembler.assemblers.MemoryModelAssembler;
import org.apache.jena.mem.GraphMemBase;
import org.apache.jena.rdf.model.*;

public class TestMemoryModelAssembler extends AssemblerTestBase {
    public TestMemoryModelAssembler(String name) {
        super(name);
    }

    @Override
    protected Class<? extends Assembler> getAssemblerClass() {
        return MemoryModelAssembler.class;
    }

    public void testMemoryModelAssemblerType() {
        testDemandsMinimalType(new MemoryModelAssembler(), JA.MemoryModel);
    }

    public void testMemoryModelAssembler() {
        Assembler a = new MemoryModelAssembler();
        Model m = a.openModel(resourceInModel("x rdf:type ja:MemoryModel"));
        assertInstanceOf(Model.class, m);
        assertInstanceOf(GraphMemBase.class, m.getGraph());
    }
}

==> jena-6.0.0-source-release.zip: jena-6.0.0/jena-core/src/test/java/org/apache/jena/assembler/test/TestMemoryModelAssembler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 *   SPDX-License-Identifier: Apache-2.0
 */

package org.apache.jena.assembler.test;

import org.apache.jena.assembler.Assembler;
import org.apache.jena.assembler.JA;
import org.apache.jena.assembler.assemblers.MemoryModelAssembler;
import org.apache.jena.rdf.model.Model;

public class TestMemoryModelAssembler extends AssemblerTestBase {
    public TestMemoryModelAssembler(String name) {
        super(name);
    }

    @Override
    protected Class<? extends Assembler> getAssemblerClass() {
        return MemoryModelAssembler.class;
    }

    public void testMemoryModelAssemblerType() {
        testDemandsMinimalType(new MemoryModelAssembler(), JA.MemoryModel);
    }

    public void testMemoryModelAssembler() {
        Assembler a = new MemoryModelAssembler();
        Model m = a.openModel(resourceInModel("x rdf:type ja:MemoryModel"));
        assertNotNull(m.getGraph());
    }
}
